@@ -22,8 +22,8 @@ class _BaseWrapper(object):
     def forward(self, image):
         self.image_shape = image.shape[2:]
         self.logits = self.model(image)
-        print(self.logits)
-        print(self.logits.shape)
+        if len(self.logits.shape) == 1:
+            self.logits = [self.logits]
         self.probs = F.softmax(self.logits, dim=1)
         return self.probs.sort(dim=1, descending=True)  # ordered results
 
